import { ApiProperty, IntersectionType, PartialType } from '@nestjs/swagger';
import { IsArray, IsNumber, IsOptional, IsString } from 'class-validator';
import { PagerDto } from '~/common/dto/pager.dto';
import { Storage } from '~/modules/tools/storage/storage.entity';
import { IsUnique } from '~/shared/database/constraints/unique.constraint';
import { SaleQuotationComponentEntity } from './sale_quotation_component.entity';

export class SaleQuotationComponentDto {
  @ApiProperty({ description: '报价配件名称' })
  @IsString()
  name: string;

  @ApiProperty({ description: '配件规格' })
  @IsOptional()
  @IsString()
  componentSpecification: string;

  @ApiProperty({ description: '配件备注' })
  @IsOptional()
  @IsString()
  remark: string;

  @ApiProperty({ description: '单位(字典)' })
  @IsOptional()
  @IsNumber()
  unitId: number;
  
  @ApiProperty({ description: '单价' })
  @IsOptional()
  @IsNumber()
  unitPrice: number;

  @ApiProperty({ description: '附件' })
  files: Storage[];
}

export class SaleQuotationComponentUpdateDto extends PartialType(SaleQuotationComponentDto) {
  @ApiProperty({ description: '附件' })
  @IsOptional()
  @IsArray()
  fileIds: number[];
}

export class ComapnyCreateDto extends PartialType(SaleQuotationComponentDto) {
  @ApiProperty({ description: '附件' })
  @IsOptional()
  @IsArray()
  fileIds: number[];
}

export class SaleQuotationComponentQueryDto extends IntersectionType(
  PagerDto<SaleQuotationComponentDto>,
  PartialType(SaleQuotationComponentDto)
) {
  @ApiProperty({ description: '报价配件名称' })
  @IsOptional()
  @IsString()
  name: string;
}
