import { ApiHideProperty, ApiProperty } from '@nestjs/swagger';
import {
  Column,
  Entity,
  JoinColumn,
  JoinTable,
  ManyToMany,
  ManyToOne,
  OneToMany,
  Relation
} from 'typeorm';
import { CommonEntity } from '~/common/entity/common.entity';
import { Storage } from '~/modules/tools/storage/storage.entity';
import { SaleQuotationGroupEntity } from '../group/sale_quotation_group.entity';
import { DictItemEntity } from '~/modules/system/dict-item/dict-item.entity';

/**
 * 报价配件实体类
 */
@Entity({ name: 'sale_quotation_component' })
export class SaleQuotationComponentEntity extends CommonEntity {
  @Column({
    name: 'name',
    type: 'varchar',
    length: 255,
    comment: '报价配件名称'
  })
  @ApiProperty({ description: '报价配件名称' })
  name: string;

  @Column({
    name: 'component_specification',
    type: 'varchar',
    nullable: true,
    length: 255,
    comment: '产品规格'
  })
  @ApiProperty({ description: '产品规格', nullable: true })
  componentSpecification?: string;

  @Column({ name: 'unit_id', type: 'int', comment: '单位(字典)', nullable: true })
  @ApiProperty({ description: '单位(字典)' })
  unitId: number;

  @ManyToOne(() => DictItemEntity)
  @JoinColumn({ name: 'unit_id' })
  unit: DictItemEntity;

  @Column({
    name: 'unit_price',
    type: 'decimal',
    precision: 15,
    default: 0,
    scale: 10,
    comment: '单价'
  })
  @ApiProperty({ description: '单价' })
  unitPrice: number;

  @Column({
    name: 'remark',
    type: 'varchar',
    length: 255,
    nullable: true,
    comment: '备注'
  })
  @ApiProperty({ description: '产品备注' })
  remark: string;

  @Column({ name: 'is_delete', type: 'tinyint', default: 0, comment: '是否删除' })
  @ApiProperty({ description: '删除状态：0未删除，1已删除' })
  isDelete: number;

  @ManyToMany(() => Storage, storage => storage.saleQuotationComponents)
  @JoinTable({
    name: 'sale_quotation_component_storage',
    joinColumn: { name: 'sale_quotation_component_id', referencedColumnName: 'id' },
    inverseJoinColumn: { name: 'file_id', referencedColumnName: 'id' }
  })
  files: Relation<Storage[]>;

  @ApiHideProperty()
  @ManyToMany(() => SaleQuotationGroupEntity, group => group.components)
  groups: Relation<SaleQuotationGroupEntity[]>;
}
