import { ApiProperty, IntersectionType, PartialType } from '@nestjs/swagger';
import { IsArray, IsNumber, IsOptional, IsString } from 'class-validator';
import { PagerDto } from '~/common/dto/pager.dto';
import { Storage } from '~/modules/tools/storage/storage.entity';
import { IsUnique } from '~/shared/database/constraints/unique.constraint';
import { SaleQuotationGroupEntity } from './sale_quotation_group.entity';

export class SaleQuotationGroupDto {
  @ApiProperty({ description: '报价分组名称' })
  @IsUnique(SaleQuotationGroupEntity, { message: '已存在同名报价分组' })
  @IsString()
  name: string;
}

export class SaleQuotationGroupUpdateDto extends PartialType(SaleQuotationGroupDto) {}

export class ComapnyCreateDto extends PartialType(SaleQuotationGroupDto) {}

export class SaleQuotationGroupQueryDto extends IntersectionType(
  PagerDto<SaleQuotationGroupDto>,
  PartialType(SaleQuotationGroupDto)
) {
  @ApiProperty({ description: '报价分组名称' })
  @IsOptional()
  @IsString()
  name: string;
}
