import { Injectable } from '@nestjs/common';
import { InjectEntityManager, InjectRepository } from '@nestjs/typeorm';
import { EntityManager, Repository } from 'typeorm';
import { Pagination } from '~/helper/paginate/pagination';
import { paginate } from '~/helper/paginate';
import { BusinessException } from '~/common/exceptions/biz.exception';
import { ErrorEnum } from '~/constants/error-code.constant';
import { fieldSearch } from '~/shared/database/field-search';
import { SaleQuotationGroupEntity } from './sale_quotation_group.entity';
import { Storage } from '~/modules/tools/storage/storage.entity';
import {
  SaleQuotationGroupDto,
  SaleQuotationGroupQueryDto,
  SaleQuotationGroupUpdateDto
} from './sale_quotation_group.dto';

@Injectable()
export class SaleQuotationGroupService {
  constructor(
    @InjectEntityManager() private entityManager: EntityManager,
    @InjectRepository(SaleQuotationGroupEntity)
    private saleQuotationGroupRepository: Repository<SaleQuotationGroupEntity>
  ) {}

  /**
   * 分页查询所有
   */
  async findAll({
    page,
    pageSize,
    ...fields
  }: SaleQuotationGroupQueryDto): Promise<Pagination<SaleQuotationGroupEntity>> {
    const queryBuilder = this.saleQuotationGroupRepository
      .createQueryBuilder('saleQuotationGroup')
      .where(fieldSearch(fields))
      .andWhere('saleQuotationGroup.isDelete = 0');

    return paginate<SaleQuotationGroupEntity>(queryBuilder, {
      page,
      pageSize
    });
  }

  /**
   * 新增
   */
  async create(dto: SaleQuotationGroupDto): Promise<void> {
    await this.saleQuotationGroupRepository.insert(dto);
  }

  /**
   * 更新
   */
  async update(id: number, data: Partial<SaleQuotationGroupUpdateDto>): Promise<void> {
    await this.entityManager.transaction(async manager => {
      await manager.update(SaleQuotationGroupEntity, id, {
        ...data
      });
    });
  }

  /**
   * 删除
   */
  async delete(id: number): Promise<void> {
    // 比较重要，做逻辑删除
    await this.saleQuotationGroupRepository.update(id, { isDelete: 1 });
  }

  /**
   * 获取单个信息
   */
  async info(id: number) {
    const info = await this.saleQuotationGroupRepository
      .createQueryBuilder('saleQuotationGroup')
      .where({
        id
      })
      .andWhere('saleQuotationGroup.isDelete = 0')
      .getOne();
    return info;
  }
}
