import { Injectable } from '@nestjs/common';
import { InjectEntityManager, InjectRepository } from '@nestjs/typeorm';
import { EntityManager, Repository } from 'typeorm';
import { Pagination } from '~/helper/paginate/pagination';
import { paginate } from '~/helper/paginate';
import { BusinessException } from '~/common/exceptions/biz.exception';
import { ErrorEnum } from '~/constants/error-code.constant';
import { fieldSearch } from '~/shared/database/field-search';
import { SaleQuotationTemplateEntity } from './sale_quotation_template.entity';
import { Storage } from '~/modules/tools/storage/storage.entity';
import {
  SaleQuotationTemplateDto,
  SaleQuotationTemplateQueryDto,
  SaleQuotationTemplateUpdateDto
} from './sale_quotation_template.dto';

@Injectable()
export class SaleQuotationTemplateService {
  constructor(
    @InjectEntityManager() private entityManager: EntityManager,
    @InjectRepository(SaleQuotationTemplateEntity)
    private saleQuotationTemplateRepository: Repository<SaleQuotationTemplateEntity>
  ) {}

  /**
   * 分页查询所有
   */
  async findAll({
    page,
    pageSize,
    ...fields
  }: SaleQuotationTemplateQueryDto): Promise<Pagination<SaleQuotationTemplateEntity>> {
    const queryBuilder = this.saleQuotationTemplateRepository
      .createQueryBuilder('saleQuotationTemplate')
      .where(fieldSearch(fields))
      .andWhere('saleQuotationTemplate.isDelete = 0').addOrderBy('saleQuotationTemplate.createdAt', 'DESC');

    return paginate<SaleQuotationTemplateEntity>(queryBuilder, {
      page,
      pageSize
    });
  }

  /**
   * 新增
   */
  async create(dto: SaleQuotationTemplateDto): Promise<void> {
    await this.saleQuotationTemplateRepository.insert(dto);
  }

  /**
   * 更新
   */
  async update(id: number, data: Partial<SaleQuotationTemplateUpdateDto>): Promise<void> {
    await this.entityManager.transaction(async manager => {
      await manager.update(SaleQuotationTemplateEntity, id, {
        ...data
      });
    });
  }

  /**
   * 删除
   */
  async delete(id: number): Promise<void> {
    // 比较重要，做逻辑删除
    await this.saleQuotationTemplateRepository.update(id, { isDelete: 1 });
  }

  /**
   * 获取单个信息
   */
  async info(id: number) {
    const info = await this.saleQuotationTemplateRepository
      .createQueryBuilder('saleQuotationTemplate')
      .where({
        id
      })
      .andWhere('saleQuotationTemplate.isDelete = 0')
      .getOne();
    return info;
  }
}
